@@ -27,7 +27,7 @@
 
 from __future__ import absolute_import
 
-from .util import (APPLICATION, TRANSPORT, YUBIKEY, FORM_FACTOR, Mode, Tlv,
+from .util import (APPLICATION, TRANSPORT, YUBIKEY, FORM_FACTOR, Tlv,
                    parse_tlvs, bytes2int, int2bytes)
 from .driver import AbstractDriver, NotSupportedError
 from enum import IntEnum, unique
@@ -173,7 +173,7 @@ class DeviceConfig(object):
         return self._get(TAG.DEVICE_FLAGS, 0)
 
 
-_NULL_DRIVER = AbstractDriver(0)
+_NULL_DRIVER = AbstractDriver(0, 0)
 _NEO_BASE_CAPABILITIES = TRANSPORT.CCID | APPLICATION.OTP | APPLICATION.OATH \
     | APPLICATION.OPGP | APPLICATION.PIV
 
@@ -187,7 +187,7 @@ class YubiKey(object):
     _can_write_config = False
 
     def __init__(self, descriptor, driver):
-        self._key_type = driver.pid.get_type()
+        self._key_type = driver.key_type
         self.device_name = self._key_type.value
         self._descriptor = descriptor
         self._driver = driver
@@ -267,6 +267,8 @@ class YubiKey(object):
         elif self._key_type == YUBIKEY.YK4:
             if self.version >= (5, 0, 0):
                 self.device_name = 'YubiKey Preview'
+            elif self.is_fips:
+                self.device_name = 'YubiKey FIPS'
 
     @property
     def driver(self):
@@ -306,7 +308,11 @@ class YubiKey(object):
 
     @property
     def mode(self):
-        return Mode.from_pid(self._driver.pid)
+        return self._driver.mode
+
+    @property
+    def is_fips(self):
+        return (4, 4, 0) <= self.version < (4, 5, 0)
 
     @mode.setter
     def mode(self, mode):
